"""Support executing the CLI by doing `python -m executable`."""
from __future__ import annotations

from executable.cli import cli

if __name__ == "__main__":
    cli()
